@@ -2,12 +2,16 @@ const AbstractHandler = require("./AbstractHandler")
 
 
 class ArrayHandler extends AbstractHandler {
+    constructor() {
+        super()
+    }
+
     process(command) {
         try {
             let processedArray = command.payload
             return processedArray
         } catch (error) {
-            return this.process_stack_trace(error, this.constructor.name)
+            throw this.process_stack_trace(error, this.constructor.name)
         }
     }
 }
