@@ -16,15 +16,24 @@ class LoadLibraryHandler extends AbstractHandler {
         let pathArray = lib.split(/[/\\]/)
         let libraryName = pathArray.length > 1 ? pathArray[pathArray.length - 1] : pathArray[0]
         libraryName = libraryName.replace('.js', '')
+
+        let moduleExports
+
         try {
-            global[libraryName] = require(lib)
+            moduleExports = require(lib)
         } catch (error) {
             try {
-                global[libraryName] = require(`${process.cwd()}/${lib}`)
+                moduleExports = require(`${process.cwd()}/${lib}`)
             } catch (error) {
                 throw this.process_stack_trace(error, this.constructor.name)
             }
         }
+        global[libraryName] = moduleExports
+
+        for (const [key, value] of Object.entries(moduleExports)) {
+            // Here, `key` is the name of the export, and `value` is the exported type itself.
+            global[key] = value
+        }
         return 0
     }
 }
