@@ -32,5 +32,7 @@ module.exports = {
     GetEnumValue: 30,
     AsRef: 31,
     AsOut: 32,
-    GetRefValue: 33
+    GetRefValue: 33,
+    EnableNamespace: 34,
+    EnableType: 35,
 }
\ No newline at end of file
