@@ -1,31 +1,31 @@
-import traceback
-
 from javonet.core.handler.AbstractHandler import AbstractHandler
-from javonet.core.handler.CommandHandler.ValueHandler import ValueHandler
-from javonet.core.handler.CommandHandler.LoadLibraryHandler import LoadLibraryHandler
-from javonet.core.handler.CommandHandler.InvokeStaticMethodHandler import InvokeStaticMethodHandler
-from javonet.core.handler.CommandHandler.SetStaticFieldHandler import SetStaticFieldHandler
-from javonet.core.handler.CommandHandler.CreateClassInstanceHandler import CreateClassInstanceHandler
-from javonet.core.handler.CommandHandler.GetStaticFieldHandler import GetStaticFieldHandler
-from javonet.core.handler.CommandHandler.ResolveInstanceHandler import ResolveInstanceHandler
-from javonet.core.handler.CommandHandler.GetTypeHandler import GetTypeHandler
-from javonet.core.handler.CommandHandler.InvokeInstanceMethodHandler import InvokeInstanceMethodHandler
-from javonet.core.handler.CommandHandler.CastingHandler import CastingHandler
-from javonet.core.handler.CommandHandler.GetInstanceFieldHandler import GetInstanceFieldHandler
-from javonet.core.handler.CommandHandler.SetInstanceFieldHandler import SetInstanceFieldHandler
-from javonet.core.handler.CommandHandler.DestructReferenceHandler import DestructReferenceHandler
-from javonet.core.handler.CommandHandler.ArrayGetItemHandler import ArrayGetItemHandler
-from javonet.core.handler.CommandHandler.ArrayGetSizeHandler import ArrayGetSizeHandler
-from javonet.core.handler.CommandHandler.ArrayGetRankHandler import ArrayGetRankHandler
-from javonet.core.handler.CommandHandler.ArraySetItemHandler import ArraySetItemHandler
-from javonet.core.handler.CommandHandler.ArrayHandler import ArrayHandler
-from javonet.core.handler.CommandHandler.GetEnumItemHandler import GetEnumItemHandler
-from javonet.core.handler.CommandHandler.GetEnumNameHandler import GetEnumNameHandler
-from javonet.core.handler.CommandHandler.GetEnumValueHandler import GetEnumValueHandler
+from javonet.core.handler.ValueHandler import ValueHandler
+from javonet.core.handler.LoadLibraryHandler import LoadLibraryHandler
+from javonet.core.handler.InvokeStaticMethodHandler import InvokeStaticMethodHandler
+from javonet.core.handler.SetStaticFieldHandler import SetStaticFieldHandler
+from javonet.core.handler.CreateClassInstanceHandler import CreateClassInstanceHandler
+from javonet.core.handler.GetStaticFieldHandler import GetStaticFieldHandler
+from javonet.core.handler.ResolveInstanceHandler import ResolveInstanceHandler
+from javonet.core.handler.GetTypeHandler import GetTypeHandler
+from javonet.core.handler.InvokeInstanceMethodHandler import InvokeInstanceMethodHandler
+from javonet.core.handler.CastingHandler import CastingHandler
+from javonet.core.handler.GetInstanceFieldHandler import GetInstanceFieldHandler
+from javonet.core.handler.SetInstanceFieldHandler import SetInstanceFieldHandler
+from javonet.core.handler.DestructReferenceHandler import DestructReferenceHandler
+from javonet.core.handler.ArrayGetItemHandler import ArrayGetItemHandler
+from javonet.core.handler.ArrayGetSizeHandler import ArrayGetSizeHandler
+from javonet.core.handler.ArrayGetRankHandler import ArrayGetRankHandler
+from javonet.core.handler.ArraySetItemHandler import ArraySetItemHandler
+from javonet.core.handler.ArrayHandler import ArrayHandler
+from javonet.core.handler.GetEnumItemHandler import GetEnumItemHandler
+from javonet.core.handler.GetEnumNameHandler import GetEnumNameHandler
+from javonet.core.handler.GetEnumValueHandler import GetEnumValueHandler
+from javonet.core.handler.EnableNamespaceHandler import EnableNamespaceHandler
+from javonet.core.handler.EnableTypeHandler import EnableTypeHandler
 
 from javonet.core.handler.HandlerDictionary import handler_dict
-from javonet.core.handler.ReferencesCache import ReferencesCache
-from javonet.core.exception.ExceptionSerializer import ExceptionSerializer
+from javonet.core.referenceCache.ReferencesCache import ReferencesCache
+from javonet.utils.exception.ExceptionSerializer import ExceptionSerializer
 from javonet.utils.CommandType import CommandType
 from javonet.utils.Command import Command
 
@@ -33,7 +33,6 @@ from javonet.utils.Command import Command
 class Handler(AbstractHandler):
 
     def __init__(self):
-
         handler_dict[CommandType.Value] = ValueHandler()
         handler_dict[CommandType.LoadLibrary] = LoadLibraryHandler()
         handler_dict[CommandType.InvokeStaticMethod] = InvokeStaticMethodHandler()
@@ -55,7 +54,8 @@ class Handler(AbstractHandler):
         handler_dict[CommandType.GetEnumItem] = GetEnumItemHandler()
         handler_dict[CommandType.GetEnumName] = GetEnumNameHandler()
         handler_dict[CommandType.GetEnumValue] = GetEnumValueHandler()
-
+        handler_dict[CommandType.EnableNamespace] = EnableNamespaceHandler()
+        handler_dict[CommandType.EnableType] = EnableTypeHandler()
 
     def handle_command(self, command):
         try:
